@@ -1,5 +1,5 @@
 from transformers import GPT2TokenizerFast
-from constants import price_per_token, engine_max_tokens
+from openai_proxy.utils.constants import price_per_token, engine_max_tokens
 
 
 def token_counter(prompt):
